@@ -141,7 +141,7 @@ cpl_error_code kmo_debug_frameset(const cpl_frameset *frameset)
         if (frameset == NULL) {
             cpl_msg_warning("", "Empty frameset!");
         } else {
-            frame  = cpl_frameset_get_first_const(frameset);
+            frame = cpl_frameset_find_const(frameset, NULL);
 
             if (KMO_TRY_GET_NEW_ERROR(void) != CPL_ERROR_NONE) {
                 KMO_TRY_RECOVER();
@@ -154,7 +154,7 @@ cpl_error_code kmo_debug_frameset(const cpl_frameset *frameset)
             while (frame != NULL) {
                 kmo_debug_frame(frame);
                 KMO_TRY_EXIT_IF_NULL(
-                    frame = cpl_frameset_get_next_const(frameset));
+                    frame = cpl_frameset_find_const(frameset, NULL));
             }
         }
         cpl_msg_debug("", "====== END FRAMESET ======");
