@@ -512,6 +512,12 @@ cpl_error_code kmo_arithmetic_2D_scalar(cpl_image *op1,
                 cpl_image_multiply(op1_noise, op1));
             KMO_TRY_EXIT_IF_ERROR(
                 cpl_image_multiply_scalar(op1_noise, op2));
+        } else if ((op1_noise != NULL) && (strcmp(op, "*") == 0)) {
+            KMO_TRY_EXIT_IF_ERROR(
+                cpl_image_multiply_scalar(op1_noise, op2));
+        } else if ((op1_noise != NULL) && (strcmp(op, "/") == 0)) {
+            KMO_TRY_EXIT_IF_ERROR(
+                kmo_image_divide_scalar(op1_noise, op2));
         }
     }
     KMO_CATCH
