@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_fit_profile.c,v 1.5 2013-04-10 12:11:33 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-04-10 12:11:33 $
- * $Revision: 1.5 $
- * $Name: not supported by cvs2svn $
- */
-
 #include <math.h>
 
 #include <cpl.h>
@@ -40,7 +32,7 @@
 
 /*----------------------------------------------------------------------------*/
 /**
-    @defgroup kmos_priv_fit_profile     Helper functions for recipe kmo_fit_profile.
+    @defgroup kmos_priv_fit_profile Helper functions for recipe kmo_fit_profile
 
     @{
  */
@@ -903,7 +895,7 @@ cpl_vector* kmo_vector_fit_lorentz(const cpl_vector *x, const cpl_vector *y,
                                  &covariance);
 //printf("### 1st FIT ###################\n");
 //kmo_debug_vector(fit_par);
-//printf("ERROR: %d\n", fit_error);
+//printf("ERROR: %d %s\n", fit_error);
         if (fit_error == CPL_ERROR_CONTINUE)
         {
             KMO_TRY_RECOVER();
@@ -1019,9 +1011,13 @@ cpl_vector* kmo_vector_fit_lorentz(const cpl_vector *x, const cpl_vector *y,
 //        KMO_CATCH_MSG();  // commented out to be more silent when
                             // kmo_remove_line() can't fit a lorentz
         cpl_vector_delete(fit_par); fit_par = NULL;
-        cpl_propertylist_delete(*pl); *pl = NULL;
+        if (pl!=NULL) {
+            cpl_propertylist_delete(*pl); 
+            *pl = NULL;
+        }
     }
 
+
     cpl_matrix_unwrap(x_mat);
     cpl_matrix_delete(covariance); covariance = NULL;
 
