@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_fits_stack.c,v 1.17 2013-06-17 11:32:05 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-06-17 11:32:05 $
- * $Revision: 1.17 $
- * $Name: not supported by cvs2svn $
- */
-
 #include <math.h>
 #include <string.h>
 
@@ -327,7 +319,7 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
             // find out if the frame is a table
             KMO_TRY_EXIT_IF_NULL(
-                frame = cpl_frameset_get_first(frameset));
+                    frame = cpl_frameset_find(frameset, NULL)) ;
 
             header = kmclipm_propertylist_load(cpl_frame_get_filename(frame), 0);
 
@@ -446,7 +438,7 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                                     sizeof(cpl_frame*)));
 
         KMO_TRY_EXIT_IF_NULL(
-            frame = cpl_frameset_get_first(frameset));
+                frame = cpl_frameset_find(frameset, NULL)) ;
 
         i = 0;
         while (frame != NULL) {
@@ -713,7 +705,7 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 kmo_strfreev(title_values); title_values = NULL;
                 KMO_TRY_CHECK_ERROR_STATE();
             }
-            frame = cpl_frameset_get_next(frameset);
+            frame = cpl_frameset_find(frameset, NULL);
 
             i++;
         }
@@ -956,13 +948,13 @@ int kmo_priv_fits_stack(cpl_parameterlist *parlist, cpl_frameset *frameset)
         if (needs_procat == 1) {
 
             // group must be set, otherwise kmo_dfs_save_main_header() fails!
-            frame = cpl_frameset_get_first(frameset);
+            frame = cpl_frameset_find(frameset, NULL);
             while (frame != NULL) {
                 if (CPL_FRAME_GROUP_NONE == cpl_frame_get_group(frame)) {
                     KMO_TRY_EXIT_IF_ERROR(
                         cpl_frame_set_group(frame, CPL_FRAME_GROUP_RAW));
                 }
-                frame = cpl_frameset_get_next(frameset);
+                frame = cpl_frameset_find(frameset, NULL);
             }
 
             KMO_TRY_EXIT_IF_ERROR(
