@@ -52,10 +52,6 @@
 
 /**@{*/
 
-int print_warning_once_tweak_std = TRUE;
-int print_warning_once_tweak_std_noise = TRUE;
-int print_warning_once_tweak_closest = TRUE;
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Add combine-parameters to parameterlist
@@ -1794,202 +1790,4 @@ cpl_error_code  kmo_check_frame_setup_sampling(cpl_frameset *frameset)
     return ret_error;
 }
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Tweak loading of TELLURIC vector
-  @param frameset     The input set-of-frames
-  @param category     The category of the image to load. Either a keyword or a
-                      string containing an integer designating the position of 
-                      the frame in the frameset to load (first = "0"). If NULL,
-                      the next frame with same keyword as accessed right before
-                      will be returned
-  @param ifu_nr       The device number (IFU or detector) to access (first = 1)
-  @param is_noise     TRUE:  the noise frame of the device is returned
-                      FALSE: the data frame of the device is returned
-  @param no_subtract  Just used for printing messages. Supply -1 if no messages
-                        are wanted
-  @return   Found telluric, NULL if none valid has been found (no error set!)
-
-  This tweak is done for reducing frustration of non-matching telluric...
-  If an IFU contains a telluric, it is returned.
-  If it doesn't contain a telluric, the closest one in numbers is returned.
-  But only if it is one the same detector, otherwise NULL is returned 
-  without error
-  Possible cpl_error_code set in this function:
-      CPL_ERROR_ILLEGAL_INPUT if any of the keywords don't match.
-      CPL_ERROR_NULL_INPUT if @code frameset or @code frame_type is empty
-*/
-/*----------------------------------------------------------------------------*/
-kmclipm_vector * kmo_tweak_load_telluric(
-        cpl_frameset    *   frameset,
-        int                 ifu_nr,
-        int                 is_noise,
-        int                 no_subtract)
-{
-    kmclipm_vector      *vec                = NULL;
-    cpl_propertylist    *header             = NULL;
-    const char          *tplid              = NULL;
-    int                 actual_msg_level    = 0,
-                        ifu_nr_telluric     = 0;
-
-    KMO_TRY
-    {
-        KMO_TRY_ASSURE(frameset != NULL, CPL_ERROR_NULL_INPUT,
-                "Not all input data provided!");
-        KMO_TRY_ASSURE((ifu_nr >= 1) && (ifu_nr <= KMOS_NR_IFUS),
-                CPL_ERROR_ILLEGAL_INPUT, "device number is negative!");
-        KMO_TRY_ASSURE((is_noise == 0) || (is_noise == 1),
-                CPL_ERROR_ILLEGAL_INPUT, "is_noise must be 0 or 1!");
-        KMO_TRY_EXIT_IF_NULL(
-            header = kmo_dfs_load_primary_header(frameset, TELLURIC));
-        KMO_TRY_EXIT_IF_NULL(
-            tplid = cpl_propertylist_get_string(header, TPL_ID));
-
-        if (strcmp(tplid, "KMOS_spec_cal_stdstar") == 0) {
-            if (print_warning_once_tweak_std) {
-                cpl_msg_warning("","************************************************************");
-                cpl_msg_warning("","* The TELLURIC frame was created using data taken with the *");
-                cpl_msg_warning("","* template 'KMOS_spec_cal_stdstar'. Therefore telluric     *");
-                cpl_msg_warning("","* spectra are only present for one IFU on each detector.   *");
-                cpl_msg_warning("","************************************************************");
-                print_warning_once_tweak_std = FALSE;
-            }
-        }
-
-        ifu_nr_telluric = kmo_tweak_find_ifu(frameset, ifu_nr);
-        if ((ifu_nr != ifu_nr_telluric) && (ifu_nr_telluric != -1) && 
-                (no_subtract != -1)) {
-            if (!no_subtract) {
-                cpl_msg_info("","        (telluric in IFU %d has been picked!)", ifu_nr_telluric);
-            } else {
-                cpl_msg_info("","For IFU %d telluric in IFU %d has been picked!", ifu_nr, ifu_nr_telluric);
-            }
-        }
-
-        actual_msg_level = cpl_msg_get_level();
-        cpl_msg_set_level(CPL_MSG_OFF);
-        if ((ifu_nr >= 1) && (ifu_nr <= 8)) {
-            vec = kmo_dfs_load_vector(frameset, TELLURIC, ifu_nr_telluric, 
-                    is_noise);
-        } else if ((ifu_nr >= 9) && (ifu_nr <= 16)) {
-            vec = kmo_dfs_load_vector(frameset, TELLURIC, ifu_nr_telluric, 
-                    is_noise);
-        } else if ((ifu_nr >= 17) && (ifu_nr <= 24)) {
-            vec = kmo_dfs_load_vector(frameset, TELLURIC, ifu_nr_telluric, 
-                    is_noise);
-        }
-        cpl_msg_set_level(actual_msg_level);
-
-        if (cpl_error_get_code() != CPL_ERROR_NONE) {
-            cpl_error_reset();
-        }
-    }
-    KMO_CATCH
-    {
-        KMO_CATCH_MSG();
-        kmclipm_vector_delete(vec); vec = NULL;
-    }
-    cpl_propertylist_delete(header); header = NULL;
-    if ((vec == NULL) && !is_noise && (no_subtract != -1)) {
-        if (!no_subtract) {
-            cpl_msg_warning("","        Couldn't find any telluric correction on this detector!");
-        } else {
-            cpl_msg_warning("","Couldn't find any telluric correction on this detector for IFU %d!", ifu_nr);
-        }
-    }
-    return vec;
-}
-
-/*----------------------------------------------------------------------------*/
-/**
-  @brief Find closest telluric IFU on the same detector
-  @param frameset The input set-of-frames
-  @param ifu_nr   The IFU number
-  @return   The IFU ID containing the closest telluric
-  Possible cpl_error_code set in this function:
-      CPL_ERROR_ILLEGAL_INPUT if any of the keywords don't match.
-      CPL_ERROR_NULL_INPUT if @code frameset or @code frame_type is empty
-*/
-/*----------------------------------------------------------------------------*/
-int kmo_tweak_find_ifu(cpl_frameset *frameset, int ifu_nr)
-{
-    int                 new_ifunr           = -1,
-                        shift               = 0,
-                        stop                = 0,
-                        det_nr_orig         = 0,
-                        det_nr_shift        = 0;
-    char                *keywordStd         = NULL;
-    cpl_propertylist    *header             = NULL;
-
-    KMO_TRY
-    {
-        KMO_TRY_ASSURE(frameset != NULL, CPL_ERROR_NULL_INPUT,
-                "Not all input data provided!");
-        KMO_TRY_ASSURE((ifu_nr > 0) && (ifu_nr <= KMOS_NR_IFUS),
-                CPL_ERROR_ILLEGAL_INPUT, "ifu_nr must be from 1 to 24!");
-
-        /* Load primary header */
-        KMO_TRY_EXIT_IF_NULL(
-            header = kmo_dfs_load_primary_header(frameset, TELLURIC));
-
-        /* Check if ifu_nr is a standard star */
-        // ESO PRO STDSTARi
-        KMO_TRY_EXIT_IF_NULL(keywordStd = cpl_sprintf("%s%d", PRO_STD, ifu_nr));
-
-        if (cpl_propertylist_has(header, keywordStd))   new_ifunr = ifu_nr;
-        cpl_free(keywordStd); keywordStd = NULL;
-
-        /* Check other IFUs on this detector for a standard star */
-        if (new_ifunr == -1) {
-            det_nr_orig = (ifu_nr - 1)/KMOS_IFUS_PER_DETECTOR + 1;
-            while (stop == 0) {
-                shift++;
-
-                // look an IFU upwards
-                det_nr_shift = (ifu_nr+shift - 1)/KMOS_IFUS_PER_DETECTOR + 1;
-                if ((det_nr_shift == det_nr_orig) && 
-                        (ifu_nr+shift <= KMOS_NR_IFUS)){
-                    // ESO PRO STDSTARi
-                    KMO_TRY_EXIT_IF_NULL(
-                        keywordStd=cpl_sprintf("%s%d", PRO_STD, ifu_nr+shift));
-
-                    if (cpl_propertylist_has(header, keywordStd)) {
-                        new_ifunr = ifu_nr+shift;
-                    }
-                    cpl_free(keywordStd); keywordStd = NULL;
-                }
-
-                // look an IFU downwards
-                if ((new_ifunr == -1) && (ifu_nr-shift >= 1)) {
-                    det_nr_shift=(ifu_nr-shift - 1)/KMOS_IFUS_PER_DETECTOR + 1;
-                    if (det_nr_shift == det_nr_orig) {
-                        // ESO PRO STDSTARi
-                        KMO_TRY_EXIT_IF_NULL(
-                            keywordStd = cpl_sprintf("%s%d", PRO_STD, 
-                                ifu_nr-shift));
-
-                        if (cpl_propertylist_has(header, keywordStd)) {
-                            new_ifunr = ifu_nr-shift;
-                        }
-                        cpl_free(keywordStd); keywordStd = NULL;
-                    }
-                }
-
-                // do we stop now?
-                if ((new_ifunr != -1) || ((ifu_nr-shift < 0) && 
-                            (ifu_nr+shift >= KMOS_IFUS_PER_DETECTOR))) {
-                    stop = 1;
-                }
-            } // end while (stop)
-        }
-    }
-    KMO_CATCH
-    {
-        KMO_CATCH_MSG();
-        new_ifunr = -1;
-    }
-    cpl_propertylist_delete(header); header = NULL;
-    return new_ifunr;
-}
-
 /** @} */
