@@ -589,181 +589,131 @@ cpl_error_code kmo_divide_blackbody(cpl_vector *ydata,
     return ret_err;
 }
 
+/*----------------------------------------------------------------------------*/
 /**
-    @brief
-        Removes arbitrary line.
-
-    @param spectrum      (Input/Output) The data values.
-    @param lambda        The abscissa of the data in microns.
-    @param atmos_model   The atmospheric model sharing the above abscissa
-    @param line_center   The spectral position of the line to remove
-    @param line_width    The width of the line to remove
-
-    @return              CPL_ERROR_NONE if the line has been removed
-                         successfully, an error otherwise.
-
-    Possible cpl_error_code set in this function:
-
-    @li CPL_ERROR_NULL_INPUT     if any of the inputs is NULL.
-    @li CPL_ERROR_ILLEGAL_INPUT  if the abscissa and ordinate haven't the
-                                 same length.
-*/
-cpl_error_code kmo_remove_line(cpl_vector *spectrum,
-                               const cpl_vector *lambda,
-                               const cpl_vector *atmos_model,
-                               double line_center,
-                               double line_width)
+  @brief  	Removes arbitrary line
+  @param spectrum      (Input/Output) The data values.
+  @param lambda        The abscissa of the data in microns.
+  @param atmos_model   The atmospheric model sharing the above abscissa
+  @param line_center   The spectral position of the line to remove
+  @param line_width    The width of the line to remove
+  @return   CPL_ERROR_NONE if the line has been removed successfully, 
+            an error otherwise.
+ */
+/*----------------------------------------------------------------------------*/
+cpl_error_code kmo_remove_line(
+        cpl_vector          *   spectrum,
+        const cpl_vector    *   lambda,
+        const cpl_vector    *   atmos_model,
+        double                  line_center,
+        double                  line_width)
 {
-    cpl_error_code      ret_err             = CPL_ERROR_NONE;
-    double              min                 = 0,
-                        temp                = 0,
-                        *pspectrum          = NULL,
-                        *pspectrum_range    = NULL,
-                        *pfit               = NULL,
-                        *pbase              = NULL,
-                        x_array[1],
-                        y_array[1];
-    int                 lowIndex            = 0,
-                        highIndex           = 0,
-                        i                   = 0,
-                        plot_it = 0;   // set it to 1 for piping two graphs to gnuplot
-    cpl_vector          *lambda_range       = NULL,
-                        *spectrum_range     = NULL,
-                        *atmos_range        = NULL,
-                        *fit                = NULL,
-                        *fit_par            = NULL,
-                        *orig_spectrum_range = NULL,
-                        *base           = NULL;
-    cpl_propertylist    *pl             = NULL;
+    cpl_vector          *   lambda_range ;
+    cpl_vector          *   spectrum_range ;
+    cpl_vector          *   atmos_range ;
+    cpl_vector          *   fit ;
+    cpl_vector          *   base ;
+    cpl_vector          *   fit_par ;
+    double              *   pfit ;
+    double              *   pspectrum ;
+    double              *   pspectrum_range ;
+    double              *   pbase ;
+    double                  x_array[1] ;
+    double                  y_array[1] ;
+    double                  min ;
+    int                     lowIndex, highIndex, i ;
 
-    KMO_TRY {
-        KMO_TRY_ASSURE((spectrum != NULL) &&
-                       (lambda != NULL) &&
-                       (atmos_model != NULL),
-                       CPL_ERROR_NULL_INPUT,
-                       "Not all input data is provided!");
-
-        KMO_TRY_ASSURE((line_center > 0.) &&
-                       (line_width > 0.),
-                       CPL_ERROR_ILLEGAL_INPUT,
-                       "line_center and line_width must be > 0.0!");
-
-        KMO_TRY_ASSURE((cpl_vector_get_size(lambda) == cpl_vector_get_size(spectrum)) &&
-                       (cpl_vector_get_size(lambda) == cpl_vector_get_size(atmos_model)),
-                       CPL_ERROR_ILLEGAL_INPUT,
-                       "All input vectors must have the same size");
-
-        lowIndex = cpl_vector_find(lambda, line_center - line_width/2);
-        KMO_TRY_EXIT_IF_NOT(lowIndex != -1);
-        highIndex = cpl_vector_find(lambda, line_center + line_width/2);
-        KMO_TRY_EXIT_IF_NOT(highIndex != -1);
-
-        KMO_TRY_EXIT_IF_NULL(
-            lambda_range = cpl_vector_extract(lambda, lowIndex, highIndex, 1));
-        KMO_TRY_EXIT_IF_NULL(
-            spectrum_range = cpl_vector_extract(spectrum, lowIndex, highIndex, 1));
-        KMO_TRY_EXIT_IF_NULL(
-            atmos_range = cpl_vector_extract(atmos_model, lowIndex, highIndex, 1));
-
-        KMO_TRY_EXIT_IF_NULL(
-            fit = cpl_vector_new(cpl_vector_get_size(spectrum_range)));
-        KMO_TRY_EXIT_IF_NULL(
-            pfit = cpl_vector_get_data(fit));
-        KMO_TRY_EXIT_IF_NULL(
-            pspectrum = cpl_vector_get_data(spectrum));
-        KMO_TRY_EXIT_IF_NULL(
-            pspectrum_range = cpl_vector_get_data(spectrum_range));
-        KMO_TRY_EXIT_IF_NULL(
-            base = cpl_vector_duplicate(spectrum_range));
-        KMO_TRY_EXIT_IF_NULL(
-            pbase = cpl_vector_get_data(base));
-
-        if (plot_it) {
-            KMO_TRY_EXIT_IF_NULL(
-                orig_spectrum_range = cpl_vector_duplicate(spectrum_range));
-        }
-
-        KMO_TRY_EXIT_IF_ERROR(
-            cpl_vector_divide(spectrum_range, atmos_range));
-
-        min = cpl_vector_get_min(spectrum_range);
-        fit_par = kmo_vector_fit_lorentz(lambda_range, spectrum_range, NULL,
-                                         line_center, min, &pl, 1);
-
-        if (fit_par == NULL) {
-            cpl_msg_warning("","   Couldn't identify the line at %g [um]!", line_center);
-            cpl_error_reset();
-
-            if (plot_it) {
-                char *ssstr = cpl_sprintf("lambda%d.fits", cnter);
-                cpl_vector_save(lambda_range, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("spectrum_orig%d.fits", cnter);
-                cpl_vector_save(orig_spectrum_range, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                cpl_vector *ddd = cpl_vector_duplicate(orig_spectrum_range);
-                cpl_vector_fill(ddd, 0);
-                ssstr = cpl_sprintf("fit%d.fits", cnter);
-                cpl_vector_save(ddd, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("base%d.fits", cnter);
-                cpl_vector_save(ddd, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("spectrum%d.fits", cnter);
-                cpl_vector_save(ddd, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                cpl_vector_delete(ddd);
-                cnter++;
-            }
-        } else {
-            for (i = 0; i < cpl_vector_get_size(fit); i++) {
-                x_array[0] = cpl_vector_get(lambda_range, i);
-                kmo_priv_lorentz1d_fnc(x_array, cpl_vector_get_data(fit_par), y_array);
-                pfit[i] = y_array[0];
-                pbase[i] = cpl_vector_get(fit_par, 0) + x_array[0] * cpl_vector_get(fit_par, 4);
-                temp = pbase[i] - pfit[i];
-                pspectrum_range[i] += temp;
-                pspectrum[lowIndex+i] += temp;
-            }
-
-            KMO_TRY_EXIT_IF_ERROR(
-                cpl_vector_multiply(spectrum_range, atmos_range));
-
-            cpl_msg_info("", "   Removed line at %g [um]", line_center);
-
-            if (plot_it) {
-                char *ssstr = cpl_sprintf("lambda%d.fits", cnter);
-                cpl_vector_save(lambda_range, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("spectrum_orig%d.fits", cnter);
-                cpl_vector_save(orig_spectrum_range, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("fit%d.fits", cnter);
-                cpl_vector_save(fit, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("base%d.fits", cnter);
-                cpl_vector_save(base, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                ssstr = cpl_sprintf("spectrum%d.fits", cnter);
-                cpl_vector_save(spectrum_range, ssstr, CPL_BPP_IEEE_DOUBLE, NULL, CPL_IO_CREATE);
-                cpl_free(ssstr);
-                cnter++;
-            }
-        }
-    } KMO_CATCH {
-        KMO_CATCH_MSG();
-        ret_err = cpl_error_get_code();
+    /* Check entries */
+    if (spectrum == NULL || lambda == NULL || atmos_model == NULL) {
+        cpl_msg_error(__func__, "Not all input data is provided") ;
+        cpl_error_set(__func__, CPL_ERROR_NULL_INPUT) ;
+        return CPL_ERROR_NULL_INPUT ;
+    }
+    if (line_center <= 0.0 || line_width <= 0.0) {
+        cpl_msg_error(__func__, "line_center and line_width must be > 0") ;
+        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
+        return CPL_ERROR_ILLEGAL_INPUT ;
+    }
+    if (cpl_vector_get_size(lambda) != cpl_vector_get_size(spectrum) ||
+            cpl_vector_get_size(lambda) != cpl_vector_get_size(atmos_model)) {
+        cpl_msg_error(__func__, "Input vectors must have the same size") ;
+        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
+        return CPL_ERROR_ILLEGAL_INPUT ;
     }
 
-    cpl_vector_delete(lambda_range); lambda_range = NULL;
-    cpl_vector_delete(spectrum_range); spectrum_range = NULL;
-    cpl_vector_delete(atmos_range); atmos_range = NULL;
-    cpl_vector_delete(fit); fit = NULL;
-    cpl_propertylist_delete(pl); pl = NULL;
-    cpl_vector_delete(fit_par); fit_par = NULL;
-    cpl_vector_delete(base); base = NULL;
+    /* Find the line  */
+    lowIndex = cpl_vector_find(lambda, line_center - line_width/2);
+    highIndex = cpl_vector_find(lambda, line_center + line_width/2);
+    if (lowIndex == -1 || highIndex == -1) {
+        cpl_msg_error(__func__, "Cannot find the line to remove") ;
+        cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
+        return CPL_ERROR_ILLEGAL_INPUT ;
+    }
+    
+    /* Extract the line from the 3 input vectorѕ */
+    lambda_range = cpl_vector_extract(lambda, lowIndex, highIndex, 1);
+    spectrum_range = cpl_vector_extract(spectrum, lowIndex, highIndex, 1);
+    atmos_range = cpl_vector_extract(atmos_model, lowIndex, highIndex, 1);
 
-    return ret_err;
+    /* Allocate */
+    fit = cpl_vector_new(cpl_vector_get_size(spectrum_range));
+    base = cpl_vector_duplicate(spectrum_range);
+
+    /* Accessors */
+    pspectrum = cpl_vector_get_data(spectrum);
+    pspectrum_range = cpl_vector_get_data(spectrum_range);
+    pbase = cpl_vector_get_data(base);
+    pfit = cpl_vector_get_data(fit);
+
+    /* Divide by atmos */
+    cpl_vector_divide(spectrum_range, atmos_range);
+
+    /*
+    if (line_center == 0.88635) {
+        cpl_plot_vector("set grid;", "t 'line to fit' w lines", "",
+                spectrum_range);
+    }
+    */
+
+    min = cpl_vector_get_min(spectrum_range);
+    if ((fit_par = kmo_vector_fit_lorentz(lambda_range, spectrum_range, NULL, 
+            line_center, min, NULL, 1)) == NULL) {
+        cpl_msg_warning("","   Couldn't identify the line at %g [um]", 
+                line_center);
+        cpl_error_reset();
+    } else {
+        for (i = 0; i < cpl_vector_get_size(fit); i++) {
+            x_array[0] = cpl_vector_get(lambda_range, i);
+            kmo_priv_lorentz1d_fnc(x_array, cpl_vector_get_data(fit_par), 
+                    y_array);
+            pfit[i] = y_array[0];
+            pbase[i] = cpl_vector_get(fit_par, 0) + 
+                x_array[0] * cpl_vector_get(fit_par, 4);
+            pspectrum_range[i] += pbase[i] - pfit[i] ;
+            pspectrum[lowIndex+i] += pbase[i] - pfit[i] ;
+        }
+        cpl_vector_delete(fit_par) ;
+
+        /*
+        if (line_center == 0.88635) {
+            cpl_plot_vector("set grid;", "t 'line to fit' w lines", "",
+                    spectrum_range);
+            cpl_plot_vector("set grid;", "t 'Fitted' w lines", "",
+                    fit);
+        }
+        */ 
+
+        cpl_vector_multiply(spectrum_range, atmos_range);
+        cpl_msg_info(__func__, "Removed line at %g [um]", line_center);
+    }
+
+    /* Deallocate */
+    cpl_vector_delete(lambda_range) ;
+    cpl_vector_delete(spectrum_range) ;
+    cpl_vector_delete(atmos_range) ;
+    cpl_vector_delete(fit) ;
+    cpl_vector_delete(base) ;
+    return CPL_ERROR_NONE;
 }
 
 /*----------------------------------------------------------------------------*/
