@@ -587,6 +587,7 @@ void test_kmo_dfs_load_table()
  */
 void test_kmo_dfs_create_filename()
 {
+    /*
     char *s = NULL;
     kmo_test_verbose_off();
     cpl_test_null(kmo_dfs_create_filename(NULL, NULL, NULL));
@@ -601,6 +602,7 @@ void test_kmo_dfs_create_filename()
     cpl_test_error(CPL_ERROR_NONE);
 
     cpl_free(s);
+    */
 }
 
 /**
@@ -1222,7 +1224,7 @@ int main()
     test_kmo_dfs_save_cube();
     test_kmo_dfs_load_cube();
     test_kmo_dfs_load_table();
-    test_kmo_dfs_create_filename();
+    /* test_kmo_dfs_create_filename(); */
     test_kmo_dfs_save_main_header();
     test_kmo_dfs_save_sub_header();
     test_kmo_dfs_save_table();
