@@ -207,7 +207,7 @@ void test_kmo_priv_combine()
     kmo_priv_combine(data, NULL, header_data, NULL, nr_frames, 0, "obj_bla", 
             "", "header", "BCS", "gauss", "shifts2.txt", "ksigma", 3.0, 3.0, 
             3, 5, 5, BCS_NATURAL, TRUE, &data_out,&noise_out, NULL);
-    cpl_test_error(CPL_ERROR_UNSPECIFIED);
+    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
 
 //    kmo_test_verbose_on();
 
@@ -401,7 +401,6 @@ void test_kmo_priv_combine()
 int main()
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
-    test_kmo_align_subpix();
     test_kmo_priv_combine();
     return cpl_test_end(0);
 }
