@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_flat-test.c,v 1.15 2013-10-11 07:59:36 aagudo Exp $
- *
+/* 
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-11 07:59:36 $
- * $Revision: 1.15 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -37,6 +29,7 @@
 #include "kmclipm_constants.h"
 
 #include "kmo_priv_flat.h"
+#include "kmo_priv_flat.c"
 #include "kmo_cpl_extensions.h"
 #include "kmo_debug.h"
 #include "kmo_cpl_extensions.h"
@@ -204,7 +197,7 @@ void test_kmo_calc_calib_frames()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        fread(ddd, sizeof(double), 4*2*m, fp);
+        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
     }
     fclose(fp);
     kmo_calc_calib_frames(slit_ids, edgepars, 0, NULL, NULL, NULL, NULL, NULL);
@@ -276,7 +269,7 @@ void test_kmo_curvature_qc()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        fread(ddd, sizeof(double), 4*2*m, fp);
+        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
     }
     fclose(fp);
     kmo_curvature_qc(edgepars, NULL, NULL, NULL, NULL, NULL, NULL);
@@ -339,7 +332,7 @@ void test_kmo_edgepars_to_table()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        fread(ddd, sizeof(double), 4*2*m, fp);
+        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
     }
     fclose(fp);
     cpl_table **edge_par = NULL;
@@ -415,7 +408,7 @@ void test_kmo_flat_interpolate_edge_parameters()
     for (i = 0; i < n; i++) {
         edgepars[i] = cpl_matrix_new(2*m, 4);
         double *ddd = cpl_matrix_get_data(edgepars[i]);
-        fread(ddd, sizeof(double), 4*2*m, fp);
+        if (fread(ddd, sizeof(double), 4*2*m, fp)) ;
 
         checksum += cpl_matrix_get_mean(edgepars[i]);
     }
@@ -439,7 +432,7 @@ void test_kmo_chebyshev_coefficients()
 {
     double in[4] = {1764.78, -0.00416616, 4.09266e-05, -1.74782e-07},
             out[4];
-    kmo_chebyshev_coefficients(in, out, 4, 1);
+    kmos_chebyshev_coefficients(in, out, 4, 1);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_abs(1764.78, out[0], 0.01);
     cpl_test_abs(-0.00416629, out[1], 1e-5);
@@ -873,9 +866,9 @@ void test_kmo_analize_slitedges_advanced()
 }
 
 /**
-    @brief   test for kmo_analyze_flat()
+    @brief   test for kmos_analyze_flat()
 */
-void test_kmo_analyze_flat()
+void test_kmos_analyze_flat()
 {
     int             i;
     cpl_image       *data,
@@ -901,7 +894,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -935,7 +928,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -970,7 +963,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 1, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -1006,7 +999,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(148.1, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(395.1, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(643.1, cpl_array_get_mean(array[2]), 0.1);
@@ -1043,7 +1036,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(386.9, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(638.2, cpl_array_get_mean(array[2]), 0.1);
@@ -1069,7 +1062,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 1, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_null(array[1]);
         cpl_test_abs(638.2, cpl_array_get_mean(array[2]), 0.1);
@@ -1106,7 +1099,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 2, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -1143,7 +1136,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 2, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(386.9, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_null(array[2]);
@@ -1180,7 +1173,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 2, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(386.9, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_null(array[2]);
@@ -1217,7 +1210,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 3, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -1254,7 +1247,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 3, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(386.9, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(638.2, cpl_array_get_mean(array[2]), 0.1);
@@ -1291,7 +1284,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 3, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
         cpl_test_null(array[2]);
@@ -1327,7 +1320,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(136.6, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(387.1, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_null(array[2]);
@@ -1363,7 +1356,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(367.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(616.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1400,7 +1393,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         kmo_test_verbose_off();
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         kmo_test_verbose_on();
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
@@ -1437,7 +1430,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         kmo_test_verbose_off();
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         kmo_test_verbose_on();
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
@@ -1475,7 +1468,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         kmo_test_verbose_off();
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         kmo_test_verbose_on();
         cpl_test_null(array[0]);
         cpl_test_abs(370.6, cpl_array_get_mean(array[1]), 0.1);
@@ -1509,7 +1502,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         cpl_array_set_int(ifu_inactive, 6, 1);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(370.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(619.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1541,7 +1534,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_null(array[1]);
         cpl_test_abs(619.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1573,7 +1566,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(370.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(619.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1610,7 +1603,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(185.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(434.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(683.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1643,7 +1636,7 @@ void test_kmo_analyze_flat()
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
         kmo_test_verbose_off();
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         kmo_test_verbose_on();
         cpl_test_null(array[0]);
         cpl_test_abs(434.6, cpl_array_get_mean(array[1]), 0.1);
@@ -1676,7 +1669,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(185.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_null(array[1]);
         cpl_test_abs(683.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1712,7 +1705,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(238.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(487.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(736.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1744,7 +1737,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_null(array[0]);
         cpl_test_abs(314.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(563.8, cpl_array_get_mean(array[2]), 0.1);
@@ -1778,7 +1771,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(138.7, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(388.8, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(638.9, cpl_array_get_mean(array[2]), 0.1);
@@ -1811,7 +1804,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(138.7, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(388.8, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(638.9, cpl_array_get_mean(array[2]), 0.1);
@@ -1844,7 +1837,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(138.7, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(388.8, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(638.9, cpl_array_get_mean(array[2]), 0.1);
@@ -1878,7 +1871,7 @@ void test_kmo_analyze_flat()
         // ifu_inactive in : 0 0 0 0 0 0 0 0
         ifu_inactive = cpl_array_new(8, CPL_TYPE_INT);
         kmo_array_fill_int(ifu_inactive, 0);
-        cpl_test_nonnull(array = kmo_analyze_flat(data, badpix, ifu_inactive));
+        cpl_test_nonnull(array = kmos_analyze_flat(data, badpix, ifu_inactive));
         cpl_test_abs(142.4, cpl_array_get_mean(array[0]), 0.1);
         cpl_test_abs(391.6, cpl_array_get_mean(array[1]), 0.1);
         cpl_test_abs(640.8, cpl_array_get_mean(array[2]), 0.1);
@@ -2036,25 +2029,24 @@ void test_kmo_calc_curvature()
 */
 int main()
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
-
-    test_kmo_create_bad_pix_flat_thresh();
-    test_kmo_calc_calib_frames();
-    test_kmo_polyfit_edge();
-    test_kmo_edge_trace();
-    test_kmo_curvature_qc();
-    test_kmo_edgepars_to_table();
-    test_kmo_flat_interpolate_edge_parameters();
-    test_kmo_chebyshev_coefficients();
-    test_kmo_split_frame();
-    test_kmo_imagelist_get_saturated();
-    test_kmo_create_line_profile();
-    test_kmo_get_slitedges();
-    test_kmo_analize_slitedges();
-    test_kmo_analize_slitedges_advanced();
-    test_kmo_analyze_flat();
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
+    /* test_kmo_create_bad_pix_flat_thresh(); */
+    /* test_kmo_calc_calib_frames(); */
+    /* test_kmo_polyfit_edge(); */
+    /* test_kmo_edge_trace(); */
+    /* test_kmo_curvature_qc(); */
+    /* test_kmo_edgepars_to_table(); */
+    /* test_kmo_flat_interpolate_edge_parameters(); */
+    /* test_kmo_chebyshev_coefficients(); */
+    /* test_kmo_split_frame(); */
+    /* test_kmo_imagelist_get_saturated(); */
+    /* test_kmo_create_line_profile(); */
+    /* test_kmo_get_slitedges(); */
+    /* test_kmo_analize_slitedges(); */
+    /* test_kmo_analize_slitedges_advanced(); */
+    /* test_kmos_analyze_flat(); */
     //test_kmo_calc_edge_pars();  // missing
-    test_kmo_calc_curvature();
+    /* test_kmo_calc_curvature(); */
 
     return cpl_test_end(0);
 }
