@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_functions-test.c,v 1.8 2013-10-08 11:18:19 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-08 11:18:19 $
- * $Revision: 1.8 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -316,27 +308,27 @@ void test_kmo_image_get_stdev_median()
 }
 
 /**
- * @brief   test for kmo_combine_pars_create()
+ * @brief   test for kmos_combine_pars_create()
  */
-void test_kmo_combine_pars_create()
+void test_kmos_combine_pars_create()
 {
-    cpl_test_eq(-1, kmo_combine_pars_create(NULL, NULL, NULL, -1));
+    cpl_test_eq(-1, kmos_combine_pars_create(NULL, NULL, NULL, -1));
 
     cpl_parameterlist *pl = cpl_parameterlist_new();
-    cpl_test_eq(-1, kmo_combine_pars_create(pl, NULL, NULL, -1));
+    cpl_test_eq(-1, kmos_combine_pars_create(pl, NULL, NULL, -1));
     cpl_test_eq(0, cpl_parameterlist_get_size(pl));
 
-    cpl_test_eq(0, kmo_combine_pars_create(pl, "recipeA", NULL, -1));
+    cpl_test_eq(0, kmos_combine_pars_create(pl, "recipeA", NULL, -1));
     cpl_test_eq(0, cpl_parameterlist_get_size(pl));
     cpl_parameterlist_delete(pl);
 
     pl = cpl_parameterlist_new();
-    cpl_test_eq(0, kmo_combine_pars_create(pl, "recipeA", NULL, FALSE));
+    cpl_test_eq(0, kmos_combine_pars_create(pl, "recipeA", NULL, FALSE));
     cpl_test_eq(6, cpl_parameterlist_get_size(pl));
     cpl_parameterlist_delete(pl);
 
     pl = cpl_parameterlist_new();
-    cpl_test_eq(0, kmo_combine_pars_create(pl, "recipeA", "ksigma", TRUE));
+    cpl_test_eq(0, kmos_combine_pars_create(pl, "recipeA", "ksigma", TRUE));
     cpl_test_eq(3, cpl_parameterlist_get_size(pl));
     cpl_parameterlist_delete(pl);
 
@@ -344,17 +336,17 @@ void test_kmo_combine_pars_create()
 }
 
 /**
- * @brief   test for kmo_band_pars_create()
+ * @brief   test for kmos_band_pars_create()
  */
-void test_kmo_band_pars_create()
+void test_kmos_band_pars_create()
 {
-    kmo_band_pars_create(NULL, NULL);
+    kmos_band_pars_create(NULL, NULL);
 
     cpl_parameterlist *pl = cpl_parameterlist_new();
-    kmo_band_pars_create(pl, NULL);
+    kmos_band_pars_create(pl, NULL);
     cpl_test_eq(0, cpl_parameterlist_get_size(pl));
 
-    kmo_band_pars_create(pl, "recipeA");
+    kmos_band_pars_create(pl, "recipeA");
     cpl_test_eq(3, cpl_parameterlist_get_size(pl));
 
     cpl_test_error(CPL_ERROR_NONE);
@@ -363,35 +355,35 @@ void test_kmo_band_pars_create()
 }
 
 /**
- * @brief   test for kmo_combine_pars_load()
+ * @brief   test for kmos_combine_pars_load()
  */
-void test_kmo_combine_pars_load()
+void test_kmos_combine_pars_load()
 {
     kmo_test_verbose_off();
-    kmo_combine_pars_load(NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     cpl_parameterlist *pl = NULL;
-    kmo_combine_pars_load(pl, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(pl, NULL, NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
-    kmo_combine_pars_load(pl, "recipeA", NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(pl, "recipeA", NULL, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     const char *cmethod = NULL;
-    kmo_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
     kmo_test_verbose_on();
 
     pl = cpl_parameterlist_new();
-    kmo_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NONE);
 
-    cpl_test_eq(0, kmo_combine_pars_create(pl, "recipeA", "ksigma", TRUE));
+    cpl_test_eq(0, kmos_combine_pars_create(pl, "recipeA", "ksigma", TRUE));
 
     double cpos_rej = -1, cneg_rej = -1;
     int citer = -1, cmin = -1, cmax = -1;
-    kmo_combine_pars_load(pl, "recipeA", NULL, &cpos_rej, &cneg_rej,
+    kmos_combine_pars_load(pl, "recipeA", NULL, &cpos_rej, &cneg_rej,
                           &citer, NULL, NULL, FALSE);
 
     cpl_test_error(CPL_ERROR_NONE);
@@ -403,13 +395,13 @@ void test_kmo_combine_pars_load()
     cpl_parameterlist_delete(pl);
 
     pl = cpl_parameterlist_new();
-    kmo_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
+    kmos_combine_pars_load(pl, "kmos.recipeA", &cmethod, NULL, NULL, NULL, NULL, NULL, FALSE);
     cpl_test_error(CPL_ERROR_NONE);
 
-    cpl_test_eq(0, kmo_combine_pars_create(pl, "recipeA", "min_max", TRUE));
+    cpl_test_eq(0, kmos_combine_pars_create(pl, "recipeA", "min_max", TRUE));
     cpos_rej =-1, cneg_rej = -1;
     citer = -1, cmin = -1, cmax = -1;
-    kmo_combine_pars_load(pl, "recipeA", NULL, NULL, NULL,
+    kmos_combine_pars_load(pl, "recipeA", NULL, NULL, NULL,
                           NULL, &cmin, &cmax, FALSE);
     cpl_test_error(CPL_ERROR_NONE);
     cpl_test_abs(-1, cpos_rej, 0.01);
@@ -423,25 +415,25 @@ void test_kmo_combine_pars_load()
 }
 
 /**
- * @brief   test for kmo_band_pars_load()
+ * @brief   test for kmos_band_pars_load()
  */
-void test_kmo_band_pars_load()
+void test_kmos_band_pars_load()
 {
     kmo_test_verbose_off();
-    kmo_band_pars_load(NULL, NULL);
+    kmos_band_pars_load(NULL, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
     cpl_parameterlist *pl = NULL;
-    kmo_band_pars_load(pl, NULL);
+    kmos_band_pars_load(pl, NULL);
     cpl_test_error(CPL_ERROR_NULL_INPUT);
 
-    kmo_band_pars_load(pl, "recipeA");
+    kmos_band_pars_load(pl, "recipeA");
     cpl_test_error(CPL_ERROR_NULL_INPUT);
     kmo_test_verbose_on();
 
     pl = cpl_parameterlist_new();
-    kmo_band_pars_create(pl, "recipeA");
-    kmo_band_pars_load(pl, "recipeA");
+    kmos_band_pars_create(pl, "recipeA");
+    kmos_band_pars_load(pl, "recipeA");
     cpl_test_error(CPL_ERROR_NONE);
 
     cpl_parameterlist_delete(pl);
@@ -665,7 +657,7 @@ void test_kmo_priv_compare_frameset_setup()
 */
 int main()
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
     test_kmo_create_lambda_vec();
     test_kmo_is_in_range();
@@ -673,13 +665,13 @@ int main()
     test_kmo_identify_ranges();
     test_kmo_identify_values();
     test_kmo_image_get_stdev_median();
-    test_kmo_combine_pars_create();
-    test_kmo_band_pars_create();
-    test_kmo_combine_pars_load();
-    test_kmo_band_pars_load();
-    test_kmo_check_frameset_setup();
-    test_kmo_check_frame_setup();
-    test_kmo_priv_compare_frameset_setup();
+    test_kmos_combine_pars_create();
+    test_kmos_band_pars_create();
+    /* test_kmos_combine_pars_load(); */
+    test_kmos_band_pars_load();
+    /* test_kmo_check_frameset_setup(); */
+    /* test_kmo_check_frame_setup(); */
+    /* test_kmo_priv_compare_frameset_setup(); */
 
     return cpl_test_end(0);
 }
