@@ -1,5 +1,4 @@
-/* $Id: kmo_priv_stats-test.c,v 1.6 2013-10-08 11:18:19 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-08 11:18:19 $
- * $Revision: 1.6 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -753,7 +745,7 @@ void test_kmo_calc_remaining()
 */
 int main()
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
     test_kmo_calc_stats_cube();
     test_kmo_calc_stats_img();
