@@ -41,68 +41,6 @@
 void kmo_test_verbose_off();
 void kmo_test_verbose_on();
 
-/**
-    @brief   Test for kmo_get_spec_type()
- */
-void test_kmo_get_spec_type()
-{
-    kmo_test_verbose_off();
-    kmo_get_spec_type(NULL, NULL, NULL);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char in[256] = "gaga";
-    kmo_get_spec_type(in, NULL, NULL);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char spec[256] = "gaga";
-    kmo_get_spec_type(in, spec, NULL);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char lum[256] = "gaga";
-    kmo_get_spec_type(in, spec, lum);
-    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
-    kmo_test_verbose_on();
-
-    strcpy(in, "G2IV");
-    strcpy(spec, "G2");
-    strcpy(lum, "IV");
-    kmo_get_spec_type(in, spec, lum);
-    cpl_test_error(CPL_ERROR_NONE);
-}
-
-/**
-    @brief   Test for kmo_get_temperature()
- */
-void test_kmo_get_temperature()
-{
-    kmo_test_verbose_off();
-    cpl_test_abs(0, kmo_get_temperature(NULL, NULL, NULL), 0.01);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char *my_path = cpl_sprintf("%s/ref_data/kmos_spec_type.fits", getenv("srcdir"));
-    cpl_table *lut = kmclipm_table_load(my_path, 1, 0);
-    cpl_free(my_path);
-    cpl_test_abs(0, kmo_get_temperature(lut, NULL, NULL), 0.01);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char spec[256] = "gaga";
-    cpl_test_abs(0, kmo_get_temperature(lut, spec, NULL), 0.01);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-
-    char lum[256] = "gaga";
-    cpl_test_abs(0, kmo_get_temperature(lut, spec, lum), 0.01);
-    cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
-
-    kmo_test_verbose_on();
-
-    strcpy(spec, "G2");
-    strcpy(lum, "IV");
-    cpl_test_abs(5300, kmo_get_temperature(lut, spec, lum), 0.01);
-    cpl_test_error(CPL_ERROR_NONE);
-
-    cpl_table_delete(lut);
-}
-
 /**
     @brief   Test for kmo_get_obj_sky_frame_table()
  */
@@ -424,8 +362,6 @@ int main()
 {
     cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
-    test_kmo_get_spec_type();
-    test_kmo_get_temperature();
     test_kmo_get_obj_sky_frame_table();
     test_kmo_collapse_object_sky_frame_table();
     test_kmo_interpolate_vector_wcs();
