@@ -1,5 +1,4 @@
-/* $Id: kmo_utils-test.c,v 1.7 2013-10-08 11:18:19 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Library
  * Copyright (C) 2007-2008 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-10-08 11:18:19 $
- * $Revision: 1.7 $
- * $Name: not supported by cvs2svn $
-*/
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -224,7 +216,7 @@ void test_kmo_identify_fits_header()
 {
     main_fits_desc       main_desc;
 
-    char *my_path = cpl_sprintf("%s/../../recipes/tests/ref_data/KMOS_dummy.fits", getenv("srcdir"));
+    char *my_path = cpl_sprintf("%s/ref_data/KMOS_dummy.fits", getenv("srcdir"));
     main_desc = kmo_identify_fits_header(my_path);
     cpl_free(my_path);
     cpl_test_eq(3, main_desc.nr_ext);
@@ -307,7 +299,7 @@ void test_kmo_free_fits_desc()
 {
     main_fits_desc       main_desc;
 
-    char *my_path = cpl_sprintf("%s/../../recipes/tests/ref_data/KMOS_dummy.fits", getenv("srcdir"));
+    char *my_path = cpl_sprintf("%s/ref_data/KMOS_dummy.fits", getenv("srcdir"));
     main_desc = kmo_identify_fits_header(my_path);
     cpl_free(my_path);
 
@@ -845,7 +837,7 @@ void test_kmo_strupper()
 */
 int main()
 {
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", CPL_MSG_WARNING);
+    cpl_test_init("<usd-help@eso.org>", CPL_MSG_WARNING);
 
     test_kmos_get_license();
     test_kmo_cut_endings();
