@@ -16,17 +16,6 @@
 
 void kmo_test_verbose_off();
 
-void test_kmos_priv_sky_tweak(cpl_imagelist *object, cpl_imagelist *sky, cpl_propertylist *header) {
-
-    cpl_imagelist *result = NULL;
-    float min_frac = .3;
-    int tbsub = 1;
-
-    result = kmos_priv_sky_tweak(object, sky, header, min_frac, tbsub, -1);
-
-    if (result != NULL) { cpl_imagelist_delete(result); }
-}
-
 /**
     @brief  
  */
