@@ -292,7 +292,7 @@ static int kmo_arithmetic(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        CPL_ERROR_NULL_INPUT,
                        "Not all input data is provided!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_arithmetic") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
