@@ -389,7 +389,7 @@ static int kmo_copy(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        "Input data hasn't correct data type "
                        "(KMOSTYPE must be F1I, F2I or F3I)!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_copy") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
