@@ -317,7 +317,7 @@ static int kmo_fit_profile(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        CPL_ERROR_ILLEGAL_INPUT,
                        "DATA isn't in the correct format (either F2I or F1I)!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_fit_profile") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
