@@ -314,7 +314,7 @@ static int kmo_rotate(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        CPL_ERROR_NULL_INPUT,
                        "A cube must be provided!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_rotate") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
