@@ -337,7 +337,7 @@ static int kmo_shift(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        CPL_ERROR_NULL_INPUT,
                        "A cube must be provided!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_shift") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
