@@ -313,7 +313,7 @@ static int kmo_stats(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        "Either a cube (F3I) or a cube and a mask (F2I) "
                        "must be provided!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_stats") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
