@@ -44,7 +44,7 @@
  *                          Functions prototypes
  *----------------------------------------------------------------------------*/
 
-static char * kmos_combine_create_used_ifus_string(const int *,const int *,int);
+static char * kmos_combine_create_ifus_string(const int *,const int *,int);
 static cpl_bivector * kmos_combine_parse_skipped(const char *) ;
 static int kmos_combine_is_skipped(const cpl_bivector *, int, int) ;
 
@@ -94,15 +94,15 @@ static char kmos_combine_description[] =
 "   DO                  KMOS                                                \n"
 "   category            Type   Explanation                  Required #Frames\n"
 "   --------            -----  -----------                  -------- -------\n"
-"   <none or any>       F3I    data frame                       Y      2-n  \n"
+"   CUBE_OBJECT         F3I    data frame                       Y      2-n  \n"
 "\n"
 "  Output files:\n"
 "\n"
 "   DO                      KMOS\n"
 "   category                Type    Explanation\n"
 "   --------                -----   -----------\n"
-"   COMBINE_<ESO PRO CATG>  F3I     Combined data cube\n"
-"   EXP_MASK_<ESO PRO CATG> F3I     Exposure time mask\n"
+"   COMBINE_                F3I     Combined data cube\n"
+"   EXP_MASK                F3I     Exposure time mask\n"
 "   SCI_COMBINED_COLL               (optional) Collapsed combined cube\n"
 "                                   (set --collapse_combined)\n"
 "---------------------------------------------------------------------------\n"
@@ -241,8 +241,9 @@ static int kmos_combine_create(cpl_plugin *plugin)
     /* --skipped_frames */
     p = cpl_parameter_new_value("kmos.kmos_combine.skipped_frames", 
             CPL_TYPE_STRING,
-            "Comma separated List of IFUs to skip for the combination. An IFU is specified with R:I."
-            "R is the index (starting at 1) of the reconstructed frame, I the IFU number", 
+            "Comma separated List of IFUs to skip for the combination. "
+            "An IFU is specified with R:I."
+            "R is the index (start 1) of the recons. frame, I the IFU nb", 
             "kmos.kmos_combine", "");
     cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "skipped_frames");
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
@@ -330,10 +331,10 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     double          cpos_rej, cneg_rej ;
     cpl_vector      *   ifus ;
     int                 citer, cmin, cmax, nr_frames, index,
-                        data_cube_counter, noise_cube_counter, flux,
-                        edge_nan, name_vec_size, found, suppress_extension,
-                        suppress_index, ifu_nr, nv, collapse_combined,
-                        mapping_id ;
+                        data_cube_counter, skip_cube_counter, 
+                        noise_cube_counter, flux, edge_nan, name_vec_size, 
+                        found, suppress_extension, suppress_index, ifu_nr, nv, 
+                        collapse_combined, mapping_id ;
     char            * tmp_str, * fn_combine, * fn_mask, * mapping_mode,
                     * name, ** name_vec, * name_loc ;
     const char      * frame_filename, * tmp_strc ;
@@ -350,6 +351,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     int             *   used_frame_idx ;
     int             *   used_ifus ;
     char            *   used_ifus_str ;
+    int             *   skip_frame_idx ;
+    int             *   skip_ifus ;
+    char            *   skip_ifus_str ;
     enum extrapolationType  extrapol_enum = NONE_CLIPPING;
     int             i, j ;
 
@@ -420,7 +424,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
     if (strcmp(skipped_frames, "")) {
         skipped_bivector = kmos_combine_parse_skipped(skipped_frames) ;
         if (skipped_bivector != NULL) 
-            cpl_msg_info(__func__, "Skip the following frames: %s", 
+            cpl_msg_info(__func__, "Skip the following IFU: %s", 
                     skipped_frames);
     } 
 
@@ -586,8 +590,11 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
 
         used_frame_idx = cpl_calloc(nr_frames*KMOS_NR_IFUS, sizeof(int)) ;
         used_ifus = cpl_calloc(nr_frames*KMOS_NR_IFUS, sizeof(int)) ;
+        skip_frame_idx = cpl_calloc(nr_frames*KMOS_NR_IFUS, sizeof(int)) ;
+        skip_ifus = cpl_calloc(nr_frames*KMOS_NR_IFUS, sizeof(int)) ;
         
         data_cube_counter = 0;
+        skip_cube_counter = 0;
         noise_cube_counter = 0;
         for (i = 0; i < nr_frames; i++) {
             tmp_str = cpl_sprintf("%d", i);
@@ -653,7 +660,12 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                 return -1 ;
                             }
                         }
-                    } 
+                    } else if (kmos_combine_is_skipped(skipped_bivector, 
+                                i+1, j)) {
+                        skip_frame_idx[skip_cube_counter] = i+1 ;
+                        skip_ifus[skip_cube_counter] = j ;
+                        skip_cube_counter++;
+                    }
                 }
             } else {
                 /* name/ifu mode (single) */
@@ -723,7 +735,12 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                 return -1 ;
                             }
                         }
-                    } 
+                    } else if (kmos_combine_is_skipped(skipped_bivector, 
+                                i+1, ifu_nr)) {
+                        skip_frame_idx[skip_cube_counter] = i+1 ;
+                        skip_ifus[skip_cube_counter] = ifu_nr ;
+                        skip_cube_counter++;
+                    }
                 } 
             }
             kmo_free_fits_desc(&desc);
@@ -731,10 +748,14 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         } 
  
         /* Create String for the output header - IFUs usage */
-        used_ifus_str = kmos_combine_create_used_ifus_string(used_frame_idx, 
+        used_ifus_str = kmos_combine_create_ifus_string(used_frame_idx, 
                 used_ifus, data_cube_counter);
         cpl_free(used_frame_idx) ;
         cpl_free(used_ifus) ;
+        skip_ifus_str = kmos_combine_create_ifus_string(skip_frame_idx, 
+                skip_ifus, skip_cube_counter);
+        cpl_free(skip_frame_idx) ;
+        cpl_free(skip_ifus) ;
 
         /* Combine data */
         exp_mask = NULL ;
@@ -762,6 +783,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
             for (i = 0; i < name_vec_size ; i++) cpl_free(name_vec[i]);
             cpl_free(name_vec);
             cpl_free(used_ifus_str) ;
+            cpl_free(skip_ifus_str) ;
             cpl_frameset_delete(rawframes) ;
             if (mapping_mode != NULL) cpl_free(mapping_mode) ;
             cpl_msg_error(__func__, "Failed Combination") ;
@@ -814,8 +836,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
         if (used_ifus_str != NULL) 
             cpl_propertylist_update_string(pro_plist, "ESO PRO USEDIFUS", 
                     used_ifus_str) ;
-        cpl_propertylist_update_string(pro_plist, "ESO PRO SKIPPEDIFUS", 
-                skipped_frames) ;
+        if (skip_ifus_str != NULL) 
+            cpl_propertylist_update_string(pro_plist, "ESO PRO SKIPPEDIFUS", 
+                    skip_ifus_str) ;
 
         /* Add REFLEX SUFFIX keyword */
         reflex_suffix = kmos_get_reflex_suffix(mapping_id,
@@ -832,6 +855,7 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
                 parlist, cpl_func);
         cpl_propertylist_delete(pro_plist) ;
         cpl_free(used_ifus_str) ;
+        cpl_free(skip_ifus_str) ;
 
         /* Clean */
         if (data_header_list[0] != NULL) {
@@ -908,9 +932,9 @@ static int kmos_combine(cpl_parameterlist *parlist, cpl_frameset *frameset)
   @return 
  */
 /*----------------------------------------------------------------------------*/
-static char * kmos_combine_create_used_ifus_string(
-        const int   *   used_frame_idx,
-        const int   *   used_ifus,
+static char * kmos_combine_create_ifus_string(
+        const int   *   frame_idx,
+        const int   *   ifus,
         int             nb)
 {
     char        out[8192] ;
@@ -918,20 +942,21 @@ static char * kmos_combine_create_used_ifus_string(
     int         i ;
 
     if (nb > 1000) return NULL ;
+    if (nb == 0) return NULL ;
     for (i=0 ; i<nb ; i++) {
         /* Build the current string */
-        if (used_frame_idx[i] < 10 && used_ifus[i] < 10) 
-            if (i==0) sprintf(tmp, "%1d:%1d", used_frame_idx[i], used_ifus[i]);
-            else sprintf(tmp, ",%1d:%1d", used_frame_idx[i], used_ifus[i]);
-        else if (used_frame_idx[i] < 10 && used_ifus[i] >= 10) 
-            if (i==0) sprintf(tmp, "%1d:%2d", used_frame_idx[i], used_ifus[i]);
-            else sprintf(tmp, ",%1d:%2d", used_frame_idx[i], used_ifus[i]);
-        else if (used_frame_idx[i] >= 10 && used_ifus[i] < 10) 
-            if (i==0) sprintf(tmp, "%2d:%1d", used_frame_idx[i], used_ifus[i]);
-            else sprintf(tmp, ",%2d:%1d", used_frame_idx[i], used_ifus[i]);
-        else if (used_frame_idx[i] >= 10 && used_ifus[i] >= 10) 
-            if (i==0) sprintf(tmp, "%2d:%2d", used_frame_idx[i], used_ifus[i]);
-            else sprintf(tmp, ",%2d:%2d", used_frame_idx[i], used_ifus[i]);
+        if (frame_idx[i] < 10 && ifus[i] < 10) 
+            if (i==0)   sprintf(tmp, "%1d:%1d", frame_idx[i], ifus[i]);
+            else        sprintf(tmp, ",%1d:%1d", frame_idx[i], ifus[i]);
+        else if (frame_idx[i] < 10 && ifus[i] >= 10) 
+            if (i==0)   sprintf(tmp, "%1d:%2d", frame_idx[i], ifus[i]);
+            else        sprintf(tmp, ",%1d:%2d", frame_idx[i], ifus[i]);
+        else if (frame_idx[i] >= 10 && ifus[i] < 10) 
+            if (i==0)   sprintf(tmp, "%2d:%1d", frame_idx[i], ifus[i]);
+            else        sprintf(tmp, ",%2d:%1d", frame_idx[i], ifus[i]);
+        else if (frame_idx[i] >= 10 && ifus[i] >= 10) 
+            if (i==0)   sprintf(tmp, "%2d:%2d", frame_idx[i], ifus[i]);
+            else        sprintf(tmp, ",%2d:%2d", frame_idx[i], ifus[i]);
         else return NULL ;
 
         if (i==0)   strcpy(out, tmp) ;
