@@ -287,7 +287,7 @@ static int kmos_dark(cpl_parameterlist * parlist, cpl_frameset * frameset)
        &cneg_rej, &citer, &cmin, &cmax, FALSE);
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_dark") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
