@@ -306,6 +306,7 @@ static int kmos_extract_spec(
             cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
             return -1 ;
         }
+    } else if (strcmp(mask_method, "mask") == 0) {
     } else if (strcmp(mask_method, "optimal") == 0) {
         kmos_combine_pars_load(parlist, "kmos.kmos_extract_spec", &cmethod,
                 &cpos_rej, &cneg_rej, &citer, &cmin, &cmax, FALSE);
@@ -316,7 +317,7 @@ static int kmos_extract_spec(
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_extract_spec") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
