@@ -34,6 +34,8 @@
 #include "kmo_priv_flat.h"
 #include "kmo_priv_functions.h"
 #include "kmo_dfs.h"
+#include "kmo_priv_combine.h"
+#include "kmos_pfits.h"
 #include "kmo_error.h"
 #include "kmo_constants.h"
 #include "kmo_cpl_extensions.h"
