@@ -206,7 +206,7 @@ static int kmos_gen_reflines(
     /* Retrieve input parameters */
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(framelist, "kmos_gen_reflines") != 1) {
+    if (kmo_dfs_set_groups(framelist) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
