@@ -1267,6 +1267,7 @@ static int kmos_std_star_compute_ifu(
     cpl_propertylist    *   tmp_head ;
     cpl_image           *   illum_corr ;
     cpl_propertylist    *   pl_psf ;
+    cpl_propertylist    *   plist ;
     double                  std_trace, factor_fwhm, spat_res, x_lo, y_lo, x_hi,
                             y_hi, loc_cen_x, loc_cen_y, r ;
     cpl_size                auto_cen_x, auto_cen_y, nx, ny ;
@@ -1276,7 +1277,8 @@ static int kmos_std_star_compute_ifu(
     cpl_vector          *   shot_noise ;
     cpl_vector          *   solar_spec ;
     double              *   ppp ;
-    double                  gain, mean_data, mean_data2, flux_scale_factor ;
+    double                  gain, mean_data, mean_data2, flux_scale_factor, 
+                            angle ;
     double              **  pvec_array ;
     double              *   ptmp_vec ;
     double              *   pstored_noisespec ;
@@ -1287,7 +1289,7 @@ static int kmos_std_star_compute_ifu(
     cpl_imagelist       *   tmp_cube ;
     cpl_vector          *   lambda_x ;
     cpl_vector          *   atmos_model ;
-    int                     i, j, k, nr_sky_pairs, npix, x, y ;
+    int                     i, j, k, nr_sky_pairs, npix, x, y, det_nr ;
  
     /* Check inputs */
     
@@ -1361,10 +1363,17 @@ static int kmos_std_star_compute_ifu(
     /* Illumination correction */
     /* Illumination noise small versus noise - skipped */
     if (illum_frame != NULL) {
-        illum_corr = kmo_dfs_load_image_frame(illum_frame, 
-                ifu_nr, FALSE, FALSE, NULL);
-        cpl_imagelist_divide_image(*out_data_cube, illum_corr);
-        cpl_image_delete(illum_corr);
+        det_nr = (ifu_nr - 1)/KMOS_IFUS_PER_DETECTOR + 1;
+        plist = kmclipm_propertylist_load(cpl_frame_get_filename(obj_frame), 0);
+        angle = kmo_dfs_get_property_double(plist, ROTANGLE);
+        cpl_propertylist_delete(plist); 
+        double dummy1 ;
+        illum_corr = kmos_illum_load(cpl_frame_get_filename(illum_frame),
+                CPL_TYPE_FLOAT, ifu_nr, angle, &dummy1) ;
+        if (illum_corr != NULL) {
+            cpl_imagelist_divide_image(*out_data_cube, illum_corr);
+            cpl_image_delete(illum_corr);
+        }
     }
 
     /* QC_STD_TRACE (distance of the PSF to the centre) */
@@ -1583,11 +1592,25 @@ static int kmos_std_star_compute_ifu(
                 for (i = 0; i < nr_lines_k; i++) 
                     kmo_remove_line(tmp_spec_data, lambda_x, atmos_model, 
                             lines_center_k[i], lines_width_k[i]);
-            else if (!strcmp(filter_id, "IZ")) 
+            else if (!strcmp(filter_id, "IZ")) {
+                /*
+                if (ifu_nr == 18) {
+                    cpl_vector_save(lambda_x, "ifu18_x.fits",
+                            CPL_TYPE_DOUBLE, NULL, CPL_IO_CREATE) ;
+                    cpl_vector_save(tmp_spec_data, "ifu18_y.fits",
+                            CPL_TYPE_DOUBLE, NULL, CPL_IO_CREATE) ;
+                }
+                if (ifu_nr == 12) {
+                    cpl_vector_save(lambda_x, "ifu12_x.fits",
+                            CPL_TYPE_DOUBLE, NULL, CPL_IO_CREATE) ;
+                    cpl_vector_save(tmp_spec_data, "ifu12_y.fits",
+                            CPL_TYPE_DOUBLE, NULL, CPL_IO_CREATE) ;
+                }
+                */
                 for (i = 0; i < nr_lines_iz; i++) 
                     kmo_remove_line(tmp_spec_data, lambda_x, atmos_model, 
                             lines_center_iz[i], lines_width_iz[i]);
-            else if (strcmp(filter_id, "YJ") == 0)
+            } else if (strcmp(filter_id, "YJ") == 0)
                 for (i = 0; i < nr_lines_yj; i++) 
                     kmo_remove_line(tmp_spec_data, lambda_x, atmos_model, 
                             lines_center_yj[i], lines_width_yj[i]);
