@@ -455,9 +455,10 @@ class DataPlotterManager(object):
         for indx in range(0, len(spec_list) ):
             c = self.cores[mod(indx, len(self.cores))]
             spectrum = spec_list[indx]
+            spec_ = [x for x in spectrum if (np.isnan(x) == False)]
             #os_factor = 1.0e-16; v_offset = os_factor * (indx+0)   #<-fixed step
-            med = np.median(spectrum)
-            mad = np.median(np.abs(spectrum - med))
+            med = np.median(spec_) if not np.isnan(np.median(spec_)) else 0
+            mad = np.median(np.abs(spec_ - med)) if not np.isnan(np.median(spec_)) else 0.1  #Once NaN always NaN assumption forced because of isnan()
             os_factor = med
             v_offset += mad*10  # cumulative version
             if lower_ybound == 0 :
