@@ -71,8 +71,14 @@ class DataPlotterManager(object):
                     group="Sky Sub.", description="Don't sky subtract object and references"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="sky_tweak",
                     group="Sky Sub.", description="Use modified sky cube for sky subtraction (TRUE or FALSE)"),
+            reflex.RecipeParameter(recipe=self.recipe_name, displayName="skip_sky_oh_align",
+                    group="Sky Sub.", description="Do not align the sky on OH lines - Only is stretch is on (0-no, 1-yes)"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="stretch",
-                    group="Sky Sub.", description="Stretch the sky for sky subtraction (0-no, 1-yes or 2-force)"),
+                    group="Sky Sub.", description="Stretch the sky for sky subtraction (0-no, 1-yes)"),
+            reflex.RecipeParameter(recipe=self.recipe_name, displayName="stretch_degree",
+                    group="Sky Sub.", description="Stretching polynomial degree."),
+            reflex.RecipeParameter(recipe=self.recipe_name, displayName="stretch_resampling",
+                    group="Sky Sub.", description="Stretching interpolation method (linear / spline)"),
             reflex.RecipeParameter(recipe=self.recipe_name, displayName="velocity_offset",
                     group="Sky Sub.", description="Specify velocity offset correction in km/s for lambda scale."),
         ]
@@ -188,7 +194,7 @@ class DataPlotterManager(object):
         widgets = list()
 
         # Files Selector radiobutton
-        self.radiobutton = reflex_plot_widgets.InteractiveRadioButtons(self.files_selector, self.setFSCallback, self.files.keys(), 0, 
+        self.radiobutton = reflex_plot_widgets.InteractiveRadioButtons(self.files_selector, self.setFSCallback, sorted(self.files.keys()), 0, 
                 title='Files Selection (Left Mouse Button)')
         widgets.append(self.radiobutton)
         
