@@ -33,6 +33,7 @@ class DataPlotterManager(object):
     star_spec_cat = "STAR_SPEC"
     telluric_cat = "TELLURIC"
     std_image_cat = "STD_IMAGE"
+    y_scalefactor = 1000
 
     def setWindowTitle(self):
         return self.recipe_name+"_interactive"
@@ -165,13 +166,14 @@ class DataPlotterManager(object):
         return widgets
 
     def setRadioCallback(self, label) :
-            
+
         # Setup the image display
         imgdisp = pipeline_display.ImageDisplay()
         imgdisp.setAspect('equal')
         imgdisp.z_lim = (self.image_std_avg[label] - self.image_std_stdev[label], self.image_std_avg[label] + 2 * self.image_std_stdev[label])
-        imgdisp.display(self.img_plot, "Median collapsed cube (STD_IMAGE)", self._data_plot_get_tooltip(label), 
-                self.image_std[label])
+        imgdisp.display(self.img_plot, "Median collapsed cube (STD_IMAGE)\nFWHM "+ r"$\simeq$ " +str( numpy.round(self.qc_spat_res[label], 2) )+ "  [arcsec]",                     self._data_plot_get_tooltip(label), self.image_std[label])
+        self.img_plot.set_xlabel("pixels")
+        self.img_plot.set_ylabel("pixels")
 
         # Define wave
         pix = numpy.arange(len(self.spec_data[label]))
@@ -180,13 +182,13 @@ class DataPlotterManager(object):
         # Plot Spectrum
         specdisp = pipeline_display.SpectrumDisplay()
         self.spec_plot.clear()
-        specdisp.setLabels("Wavelength (microns)", "Flux (ADU)")
+        specdisp.setLabels(r"$\lambda$["+"$\mu$m]", "Flux (ADU)   [x"+str(self.y_scalefactor)+"]" )
         specdisp.display(self.spec_plot, "Extracted Standard Star Spectrum (STAR_SPEC)", self._data_plot_get_tooltip(label), 
-                wave, self.spec_data[label])
+                wave, self.spec_data[label]/self.y_scalefactor) # TO DO: Unify plotting in one function.
 
         if (self.spec_noise[label] is not None):
             # Overplot the Noise spectrum
-            specdisp.overplot(self.spec_plot, wave, self.spec_noise[label], 'red')
+            specdisp.overplot(self.spec_plot, wave, self.spec_noise[label]/self.y_scalefactor, 'red')   # TO DO: Unify plotting in one function.
             self.spec_plot.legend(('Flux', 'Noise'))
 
     def _add_subplots(self, figure):
@@ -213,8 +215,10 @@ class DataPlotterManager(object):
         imgdisp = pipeline_display.ImageDisplay()
         imgdisp.setAspect('equal')
         imgdisp.z_lim = (self.image_std_avg[extname] - self.image_std_stdev[extname], self.image_std_avg[extname] + 2 * self.image_std_stdev[extname])
-        imgdisp.display(self.img_plot, "Median collapsed cube (STD_IMAGE)", self._data_plot_get_tooltip(extname), 
-                self.image_std[extname])
+        imgdisp.display(self.img_plot,  "Median collapsed cube (STD_IMAGE)\nFWHM "+ r"$\simeq$ " +str( numpy.round(self.qc_spat_res[extname], 2) )+ "  [arcsec]",                    self._data_plot_get_tooltip(extname), self.image_std[extname])  
+        #Please alert if it shuld be latex "\approx" instead of "\simeq".
+        self.img_plot.set_xlabel("pixels")
+        self.img_plot.set_ylabel("pixels")
 
         # Define wave
         pix = numpy.arange(len(self.spec_data[extname]))
@@ -222,13 +226,12 @@ class DataPlotterManager(object):
         
         # Plot Spectrum
         specdisp = pipeline_display.SpectrumDisplay()
-        specdisp.setLabels("Wavelength (microns)", "Flux (ADU)")
-        specdisp.display(self.spec_plot, "Extracted Standard Star Spectrum (STAR_SPEC)", self._data_plot_get_tooltip(extname), 
-                wave, self.spec_data[extname])
+        specdisp.setLabels(r"$\lambda$["+"$\mu$m]", "Flux (ADU)   [x"+str(self.y_scalefactor)+"]" )
+        specdisp.display(self.spec_plot, "Extracted Standard Star Spectrum (STAR_SPEC)", self._data_plot_get_tooltip(extname), wave, self.spec_data[extname]/self.y_scalefactor) # TO DO: Unify plotting in one function.
 
         if (self.spec_noise[extname] is not None):
             # Overplot the Noise spectrum
-            specdisp.overplot(self.spec_plot, wave, self.spec_noise[extname], 'red')
+            specdisp.overplot(self.spec_plot, wave, self.spec_noise[extname]/self.y_scalefactor, 'red') # TO DO: Unify plotting in one function.
             self.spec_plot.legend(('Flux', 'Noise'))
 
     def _add_nodata_subplots(self, figure):
